@@ -3,7 +3,7 @@ setGeneric( "bytesize", function(object, ...){
 	standardGeneric( "bytesize" )
 } )
 setMethod( "bytesize", "Message", function(object, ...){
-	.Call( "get_message_bytesize", object@pointer, PACKAGE = "RProtoBuf" )
+	.Call( "Message__bytesize", object@pointer, PACKAGE = "RProtoBuf" )
 } )
 
 setGeneric( "size", function( object, field, ... ){
@@ -12,7 +12,7 @@ setGeneric( "size", function( object, field, ... ){
 setMethod( "size", "Message", function(object, field, ...){
 	
 	if( is.character( field ) || is.numeric( field ) ){
-		.Call( "get_field_size", object@pointer, field, PACKAGE = "RProtoBuf" )
+		.Call( "Message__field_size", object@pointer, field, PACKAGE = "RProtoBuf" )
 	} else{
 		stop( "field should be a character or a number" )
 	}
