@@ -20,7 +20,6 @@
 
 #include "rprotobuf.h" 
 #include "fieldtypes.h" 
-/* :tabSize=4:indentSize=4:noTabs=false:folding=explicit:collapseFolds=1: */
 
 namespace rprotobuf{
 
@@ -386,6 +385,8 @@ PRINT_DEBUG_INFO( "value", value ) ;
 		if( field_type == TYPE_STRING || field_type == TYPE_BYTES ){
 			if( TYPEOF(value) == RAWSXP ){
 				value_size = 1 ;
+            } else if( TYPEOF(value) == STRSXP ){
+                value_size = LENGTH(value);
 			} else if( TYPEOF(value) == S4SXP && Rf_inherits( value, "Message") ){
 				value_size = 1 ; /* we will store the message payload */
 			} else if( TYPEOF(value) == VECSXP && allAreMessages( value ) ){
@@ -1116,4 +1117,3 @@ RCPP_FUNCTION_VOID_2( update_message, Rcpp::XPtr<GPB::Message> message, Rcpp::Li
 }
 
 } // namespace rprotobuf
-
